@@ -1,14 +1,5 @@
 #!/usr/bin/env python3
 
-_license_text = \
-"""/*
-    SPDX-FileCopyrightText: 2017 Klarälvdalens Datakonsult AB a KDAB Group company info@kdab.com
-    SPDX-FileContributor: Sérgio Martins <sergio.martins@kdab.com>
-
-    SPDX-License-Identifier: LGPL-2.0-or-later
-*/
-"""
-
 import sys, os, json, argparse, datetime, io, subprocess
 from shutil import copyfile
 
@@ -17,9 +8,11 @@ _checks = []
 _specified_check_names = []
 _available_categories = []
 
+
 def checkSortKey(check):
     return str(check.level) + check.name
 
+
 def level_num_to_enum(n):
     if n == -1:
         return 'ManualCheckLevel'
@@ -28,6 +21,7 @@ def level_num_to_enum(n):
 
     return 'CheckLevelUndefined'
 
+
 def level_num_to_name(n):
     if n == -1:
         return 'Manual Level'
@@ -36,6 +30,7 @@ def level_num_to_name(n):
 
     return 'undefined'
 
+
 def level_num_to_cmake_readme_variable(n):
     if n == -1:
         return 'README_manuallevel_FILES'
@@ -44,24 +39,30 @@ def level_num_to_cmake_readme_variable(n):
 
     return 'undefined'
 
+
 def clazy_source_path():
     return os.path.abspath(os.path.dirname(os.path.realpath(__file__)) + "/..") + "/"
 
+
 def templates_path():
     return clazy_source_path() + "dev-scripts/templates/"
 
+
 def docs_relative_path():
     return "docs/checks/"
 
+
 def docs_path():
     return clazy_source_path() + docs_relative_path()
 
+
 def read_file(filename):
     f = io.open(filename, 'r', newline='\n', encoding='utf8')
     contents = f.read()
     f.close()
     return contents
 
+
 def write_file(filename: str, contents):
     f = io.open(filename, 'w', newline='\n', encoding='utf8')
     f.write(contents)
@@ -69,12 +70,14 @@ def write_file(filename: str, contents):
     if filename.endswith('.h') or filename.endswith('.cpp'):
         subprocess.run(['clang-format', '-i', filename])
 
+
 def get_copyright():
     year = datetime.datetime.now().year
     author = os.getenv('GIT_AUTHOR_NAME', 'Author')
     email = os.getenv('GIT_AUTHOR_EMAIL', 'your@email')
     return "Copyright (C) %s %s <%s>" % (year, author, email)
 
+
 class Check:
     def __init__(self):
         self.name = ""
@@ -85,6 +88,9 @@ class Check:
         self.fixits = []
         self.visits_stmts = False
         self.visits_decls = False
+        self.preprocessor_callbacks = False
+        self.visit_all_typedefs = False
+        self.can_ignore_includes = False
         self.ifndef = ""
 
     def include(self): # Returns for example: "returning-void-expression.h"
@@ -217,6 +223,15 @@ def load_json(filename):
         if 'visits_decls' in check:
             c.visits_decls = check['visits_decls']
 
+        if 'preprocessor_callbacks' in check:
+            c.preprocessor_callbacks = check['preprocessor_callbacks']
+
+        if 'visit_all_typedefs' in check:
+            c.visit_all_typedefs = check['visit_all_typedefs']
+
+        if 'can_ignore_includes' in check:
+            c.can_ignore_includes = check['can_ignore_includes']
+
         if 'fixits' in check:
             for fixit in check['fixits']:
                 if 'name' not in fixit:
@@ -232,24 +247,27 @@ def load_json(filename):
     _checks = sorted(_checks, key=checkSortKey)
     return True
 
+
 def print_checks(checks):
     for c in checks:
         print(c.name + " " + str(c.level) + " " + str(c.categories))
 
-#-------------------------------------------------------------------------------
+
 def generate_register_checks(checks):
-    text = '#include "checkmanager.h"\n'
+    text = '#include "checkbase.h"\n#include "checkmanager.h"\n'
     for c in checks:
         text += '#include "' + c.qualified_include() + '"\n'
-    text += \
-"""
-template <typename T>
-RegisteredCheck check(const char *name, CheckLevel level, RegisteredCheck::Options options = RegisteredCheck::Option_None)
+    text += """
+template<typename T>
+RegisteredCheck check(const char *name, CheckLevel level, RegisteredCheck::Options options, bool canIgnoreIncludes)
 {
-    auto factoryFuntion = [name](ClazyContext *context){ return new T(name, context); };
+    auto factoryFuntion = [canIgnoreIncludes, name]() {
+        return new T(name, canIgnoreIncludes ? CheckBase::Option_CanIgnoreIncludes : CheckBase::Option_None);
+    };
     return RegisteredCheck{name, level, factoryFuntion, options};
 }
 
+// clang-format off
 void CheckManager::registerChecks()
 {
 """
@@ -260,14 +278,23 @@ void CheckManager::registerChecks()
             qtflags += " | RegisteredCheck::Option_VisitsStmts"
         if c.visits_decls:
             qtflags += " | RegisteredCheck::Option_VisitsDecls"
+        if c.preprocessor_callbacks:
+            qtflags += " | RegisteredCheck::Option_PreprocessorCallbacks"
+        if c.visit_all_typedefs:
+            qtflags += " | RegisteredCheck::Option_VisitAllTypeDefs"
 
-        qtflags = qtflags.replace("RegisteredCheck::Option_None |", "")
+        qtflags = qtflags.replace("RegisteredCheck::Option_None | ", "")
 
         if c.ifndef:
             text += "#ifndef " + c.ifndef + "\n"
 
-        text += '    registerCheck(check<%s>("%s", %s, %s));\n' % (c.get_class_name(), c.name, level_num_to_enum(c.level), qtflags)
-
+        text += '    registerCheck(check<%s>("%s", %s, %s, %s));\n' % (
+            c.get_class_name(),
+            c.name,
+            level_num_to_enum(c.level),
+            qtflags,
+            "true" if c.can_ignore_includes else "false"
+        )
         fixitID = 1
         for fixit in c.fixits:
             text += '    registerFixIt(%d, "%s", "%s");\n' % (fixitID, "fix-" + fixit, c.name)
@@ -278,14 +305,15 @@ void CheckManager::registerChecks()
 
     text += "}\n"
 
-    comment_text = \
-"""
+    comment_text = """
 /**
  * New scripts should be added to the check.json file and the files should be regenerated
  * ./dev-scripts/generate.py --generate
+ * SPDX-License-Identifier: CC0-1.0
+ * SPDX-FileCopyrightText: Clazy Developers
  */
 """
-    text = _license_text + '\n' + comment_text + '\n' + text
+    text = comment_text + '\n' + text
     filename = clazy_source_path() + "src/Checks.h"
 
     old_text = read_file(filename)
@@ -294,9 +322,10 @@ void CheckManager::registerChecks()
         print("Generated " + filename)
         return True
     return False
-#-------------------------------------------------------------------------------
+
+
 def generate_cmake_file(checks):
-    text = "# This file was autogenerated by running: ./dev-scripts/generate.py --generate\n\nset(CLAZY_CHECKS_SRCS ${CLAZY_CHECKS_SRCS}\n"
+    text = "# This file was autogenerated by running: ./dev-scripts/generate.py --generate\n# SPDX-License-Identifier: CC0-1.0\n# SPDX-FileCopyrightText: Clazy Developers\n\nset(CLAZY_CHECKS_SRCS ${CLAZY_CHECKS_SRCS}\n"
     for level in [-1, 0, 1, 2, 3]:
         for check in checks:
             if check.level == level:
@@ -310,7 +339,8 @@ def generate_cmake_file(checks):
         print("Generated " + filename)
         return True
     return False
-#-------------------------------------------------------------------------------
+
+
 def create_readmes(checks):
     generated = False
     for check in checks:
@@ -328,7 +358,8 @@ def create_readmes(checks):
                 print("Created " + check.readme_path())
             generated = True
     return generated
-#-------------------------------------------------------------------------------
+
+
 def create_unittests(checks):
     generated = False
     for check in checks:
@@ -351,7 +382,7 @@ def create_unittests(checks):
             generated = True
     return generated
 
-#-------------------------------------------------------------------------------
+
 def search_in_all_levels(filename):
     for level in ['manuallevel', 'level0', 'level1', 'level2']:
         complete_filename = clazy_source_path() + 'src/checks/' + level + '/' + filename
@@ -359,7 +390,7 @@ def search_in_all_levels(filename):
             return complete_filename
     return ""
 
-#-------------------------------------------------------------------------------
+
 def create_checks(checks):
     generated = False
 
@@ -415,25 +446,25 @@ def create_checks(checks):
             print('Edited Changelog')
 
     return generated
-#-------------------------------------------------------------------------------
+
+
 def generate_readme(checks):
     filename = clazy_source_path() + "README.md"
     f = io.open(filename, 'r', newline='\n', encoding='utf8')
-    old_contents = f.readlines();
-    f.close();
+    old_contents = f.readlines()
+    f.close()
 
     new_text_to_insert = ""
     for level in ['-1', '0', '1', '2']:
-        new_text_to_insert += "- Checks from %s:" % level_num_to_name(int(level)) + "\n"
+        new_text_to_insert += "- Checks from %s:" % level_num_to_name(int(level)) + "\n\n"
         for c in checks:
             if str(c.level) == level:
                 fixits_text = c.fixits_text()
                 if fixits_text:
-                    fixits_text = "    " + fixits_text
-                new_text_to_insert += "    - [%s](%sREADME-%s.md)%s" % (c.name, docs_relative_path(), c.name, fixits_text) + "\n"
+                    fixits_text = " " + fixits_text
+                new_text_to_insert += "  - [%s](%sREADME-%s.md)%s" % (c.name, docs_relative_path(), c.name, fixits_text) + "\n"
         new_text_to_insert += "\n"
 
-
     f = io.open(filename, 'w', newline='\n', encoding='utf8')
 
     skip = False
@@ -453,54 +484,41 @@ def generate_readme(checks):
     f.close()
 
     f = io.open(filename, 'r', newline='\n', encoding='utf8')
-    new_contents = f.readlines();
-    f.close();
+    new_contents = f.readlines()
+    f.close()
 
     if old_contents != new_contents:
         print("Generated " + filename)
         return True
     return False
-#-------------------------------------------------------------------------------
+
+
 def generate_ctest(checks):
     # Generates the ClazyTests.cmake file
     filename = clazy_source_path() + 'ClazyTests.generated.cmake'
 
-    contents = """# This file was autogenerated by running: ./dev-scripts/generate.py --generate\n
-if ($ENV{CI_JOB_NAME_SLUG} MATCHES "qt5")
-    set(TEST_VERSION_OPTION "--qt-versions=5")
-elseif($ENV{CI_JOB_NAME_SLUG} MATCHES "qt6")
-    set(TEST_VERSION_OPTION "--qt-versions=6")
-endif()
-
-macro(add_clazy_test name)
-  add_test(NAME ${name} COMMAND python3 run_tests.py ${name} --verbose ${TEST_VERSION_OPTION} WORKING_DIRECTORY ${CMAKE_SOURCE_DIR}/tests/)
-  if (CLANG_EXECUTABLE_PATH)
-    set(CLANG_CXX_TEST "CLANGXX=${CLANG_EXECUTABLE_PATH};")
-  endif()
-  set_property(TEST ${name} PROPERTY
-    ENVIRONMENT "${CLANG_CXX_TEST}CLAZYPLUGIN_CXX=$<TARGET_FILE:ClazyPlugin>;CLAZYSTANDALONE_CXX=$<TARGET_FILE:clazy-standalone>;$<$<BOOL:${HAS_STD_FILESYSTEM}>:CLAZY_HAS_FILESYSTEM=>"
-  )
-endmacro()\n
+    contents = f"""
+# This file was autogenerated by running: ./dev-scripts/generate.py --generate
+# SPDX-License-Identifier: CC0-1.0
+# SPDX-FileCopyrightText: Clazy Developers
+{'\n'.join(f"add_clazy_test({c.name})" for c in checks)}
+add_clazy_test(clazy-standalone)
+add_clazy_test(clazy)
 """
-    for c in checks:
-        contents += 'add_clazy_test(%s)\n' % (c.name)
-
-
-    contents += 'add_clazy_test(clazy-standalone)\n'
-    contents += 'add_clazy_test(clazy)\n'
 
     f = io.open(filename, 'w', newline='\n', encoding='utf8')
     f.write(contents)
     f.close()
     return True
-#-------------------------------------------------------------------------------
+
+
 def generate_readmes_cmake_install(checks):
     old_contents = ""
     filename = clazy_source_path() + 'readmes.cmake'
     if os.path.exists(filename):
         f = io.open(filename, 'r', newline='\n', encoding='utf8')
-        old_contents = f.readlines();
-        f.close();
+        old_contents = f.readlines()
+        f.close()
 
     new_text_to_insert = ""
     for level in ['-1', '0', '1', '2']:
@@ -518,7 +536,6 @@ def generate_readmes_cmake_install(checks):
     f.close()
     return True
 
-#-------------------------------------------------------------------------------
 
 complete_json_filename = clazy_source_path() + CHECKS_FILENAME
 
@@ -526,8 +543,6 @@ if not os.path.exists(complete_json_filename):
     print("File doesn't exist: " + complete_json_filename)
     exit(1)
 
-
-
 parser = argparse.ArgumentParser()
 parser.add_argument("--generate", action='store_true', help="Generate src/Checks.h, CheckSources.cmake and README.md")
 parser.add_argument("checks", nargs='*', help="Optional check names to build. Useful to speedup builds during development, by building only the specified checks. Default is to build all checks.")
