@@ -1,22 +1,7 @@
 /*
-  This file is part of the clazy static checker.
+    SPDX-FileCopyrightText: 2016 Sergio Martins <smartins@kde.org>
 
-    Copyright (C) 2016 Sergio Martins <smartins@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef CLAZY_CONTEXT_UTILS_H
@@ -24,17 +9,18 @@
 
 #include "TypeUtils.h"
 
-#include <clang/AST/DeclBase.h>
 #include <clang/AST/Decl.h>
+#include <clang/AST/DeclBase.h>
 #include <clang/AST/DeclCXX.h>
 #include <clang/AST/Stmt.h>
 #include <clang/AST/Type.h>
 #include <llvm/Support/Casting.h>
 
-#include <vector>
 #include <string>
+#include <vector>
 
-namespace clang {
+namespace clang
+{
 class ValueDecl;
 class DeclContext;
 class SourceManager;
@@ -45,7 +31,6 @@ class ParentMap;
 
 namespace clazy
 {
-
 /**
  * Returns true if a decl is inside a function, instead of say a class field.
  * This returns true if "QList<int> l;" is a local variable, instead of being a class field such
@@ -53,8 +38,8 @@ namespace clazy
  */
 inline bool isValueDeclInFunctionContext(const clang::ValueDecl *valueDecl)
 {
-    auto context = valueDecl ? valueDecl->getDeclContext() : nullptr;
-    return context && llvm::isa<clang::FunctionDecl>(context) && !llvm::isa<clang::ParmVarDecl>(valueDecl);
+    const auto *context = valueDecl ? valueDecl->getDeclContext() : nullptr;
+    return llvm::isa_and_nonnull<clang::FunctionDecl>(context) && !llvm::isa<clang::ParmVarDecl>(valueDecl);
 }
 
 /**
@@ -66,26 +51,30 @@ std::vector<clang::DeclContext *> contextsForDecl(clang::DeclContext *);
 /**
  * Returns the first context for a decl.
  */
-inline clang::DeclContext * contextForDecl(clang::Decl *decl)
+inline clang::DeclContext *contextForDecl(clang::Decl *decl)
 {
-    if (!decl)
+    if (!decl) {
         return nullptr;
+    }
 
-    if (auto context = llvm::dyn_cast<clang::DeclContext>(decl))
+    if (auto *context = llvm::dyn_cast<clang::DeclContext>(decl)) {
         return context;
+    }
 
     return decl->getDeclContext();
 }
 
 inline clang::NamespaceDecl *namespaceForDecl(clang::Decl *decl)
 {
-    if (!decl)
+    if (!decl) {
         return nullptr;
+    }
 
     clang::DeclContext *declContext = decl->getDeclContext();
     while (declContext) {
-        if (auto ns = llvm::dyn_cast<clang::NamespaceDecl>(declContext))
+        if (auto *ns = llvm::dyn_cast<clang::NamespaceDecl>(declContext)) {
             return ns;
+        }
 
         declContext = declContext->getParent();
     }
@@ -95,19 +84,21 @@ inline clang::NamespaceDecl *namespaceForDecl(clang::Decl *decl)
 
 inline clang::NamespaceDecl *namespaceForType(clang::QualType q)
 {
-    if (q.isNull())
+    if (q.isNull()) {
         return nullptr;
+    }
 
     q = clazy::pointeeQualType(q);
     // Check if it's a class, struct, union or enum
     clang::TagDecl *rec = q->getAsTagDecl();
-    if (rec)
+    if (rec) {
         return namespaceForDecl(rec);
+    }
 
     // Or maybe it's a typedef to a builtin type:
-    auto typeDefType = q->getAs<clang::TypedefType>();
+    const auto *typeDefType = q->getAs<clang::TypedefType>();
     if (typeDefType) {
-        clang::TypedefNameDecl* typedeff = typeDefType->getDecl();
+        clang::TypedefNameDecl *typedeff = typeDefType->getDecl();
         return namespaceForDecl(typedeff);
     }
 
@@ -116,8 +107,9 @@ inline clang::NamespaceDecl *namespaceForType(clang::QualType q)
 
 inline clang::NamespaceDecl *namespaceForFunction(clang::FunctionDecl *func)
 {
-    if (auto ns = llvm::dyn_cast<clang::NamespaceDecl>(func->getDeclContext()))
+    if (auto *ns = llvm::dyn_cast<clang::NamespaceDecl>(func->getDeclContext())) {
         return ns;
+    }
 
     return namespaceForDecl(func);
 }
@@ -127,19 +119,20 @@ inline clang::NamespaceDecl *namespaceForFunction(clang::FunctionDecl *func)
  * Contexts are namespaces, classes, inner classes, functions, etc.
 
  */
-template <typename T>
-T* firstContextOfType(clang::DeclContext *context)
+template<typename T>
+T *firstContextOfType(clang::DeclContext *context)
 {
-    if (!context)
+    if (!context) {
         return nullptr;
+    }
 
-    if (llvm::isa<T>(context))
+    if (llvm::isa<T>(context)) {
         return llvm::cast<T>(context);
+    }
 
     return clazy::firstContextOfType<T>(context->getParent());
 }
 
-
 /**
  * Returns fully/semi-fully qualified name for a method, but doesn't over-qualify with namespaces
  * which we're already in.
@@ -163,9 +156,7 @@ std::string getMostNeededQualifiedName(const clang::SourceManager &sourceManager
  * but only if you qualify it with the derived class name, so &Derived::baseMethod, instead of &Base::baseMethod
  * If this was the case then isSpecialProtectedCase will be true
  */
-bool canTakeAddressOf(clang::CXXMethodDecl *method,
-                      clang::DeclContext *context,
-                      bool &isSpecialProtectedCase);
+bool canTakeAddressOf(clang::CXXMethodDecl *method, clang::DeclContext *context, bool &isSpecialProtectedCase);
 
 }
 
