@@ -73,11 +73,7 @@ inline bool classImplementsMethod(const clang::CXXRecordDecl *record, const clan
 
     llvm::StringRef methodName = clazy::name(method);
     for (auto *m : record->methods()) {
-#if LLVM_VERSION_MAJOR >= 18
         if (!m->isPureVirtual() && clazy::name(m) == methodName && parametersMatch(m, method)) {
-#else
-        if (!m->isPure() && clazy::name(m) == methodName && parametersMatch(m, method)) {
-#endif
             return true;
         }
     }
