@@ -1,22 +1,7 @@
 /*
-    This file is part of the clazy static checker.
+    SPDX-FileCopyrightText: 2016 Sergio Martins <smartins@kde.org>
 
-    Copyright (C) 2016 Sergio Martins <smartins@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef CLAZY_MACRO_UTILS_H
@@ -25,21 +10,21 @@
 #include "clazy_stl.h"
 
 #include <clang/AST/ASTContext.h>
+#include <clang/Basic/SourceLocation.h>
 #include <clang/Frontend/CompilerInstance.h>
 #include <clang/Lex/Lexer.h>
 #include <clang/Lex/PreprocessorOptions.h>
-#include <clang/Basic/SourceLocation.h>
 
 #include <vector>
 
-namespace clang {
+namespace clang
+{
 class CompilerInstance;
 class SourceLocation;
 }
 
 namespace clazy
 {
-
 /**
  * Returns true is macroName was defined via compiler invocation argument.
  * Like $ gcc -Dfoo main.cpp
@@ -49,8 +34,9 @@ inline bool isPredefined(const clang::PreprocessorOptions &ppOpts, const llvm::S
     const auto &macros = ppOpts.Macros;
 
     for (const auto &macro : macros) {
-        if (macro.first == macroName)
+        if (macro.first == macroName) {
             return true;
+        }
     }
 
     return false;
@@ -75,8 +61,8 @@ inline bool isInMacro(const clang::ASTContext *context, clang::SourceLocation lo
 inline bool isInAnyMacro(const clang::ASTContext *context, clang::SourceLocation loc, const std::vector<llvm::StringRef> &macroNames)
 {
     return clazy::any_of(macroNames, [context, loc](const llvm::StringRef &macroName) {
-            return isInMacro(context, loc, macroName);
-        });
+        return isInMacro(context, loc, macroName);
+    });
 }
 
 }
