@@ -25,11 +25,12 @@ class CXXMethodDecl;
 class DetachingBase : public CheckBase
 {
 public:
-    explicit DetachingBase(const std::string &name, ClazyContext *context, Options = Option_None);
+    explicit DetachingBase(const std::string &name, Options = Option_None);
 
 protected:
     enum DetachingMethodType { DetachingMethod, DetachingMethodWithConstCounterPart };
 
+    std::vector<clang::FixItHint> getFixitHints(llvm::StringRef className, llvm::StringRef functionName, clang::CallExpr *callExpr) const;
     bool isDetachingMethod(clang::CXXMethodDecl *, DetachingMethodType = DetachingMethod) const;
 };
 
