@@ -20,11 +20,6 @@
 
 using namespace clang;
 
-LambdaUniqueConnection::LambdaUniqueConnection(const std::string &name, ClazyContext *context)
-    : CheckBase(name, context, Option_CanIgnoreIncludes)
-{
-}
-
 void LambdaUniqueConnection::VisitStmt(clang::Stmt *stmt)
 {
     auto *call = dyn_cast<CallExpr>(stmt);
