@@ -17,11 +17,6 @@
 
 using namespace clang;
 
-QFileInfoExists::QFileInfoExists(const std::string &name, ClazyContext *context)
-    : CheckBase(name, context, Option_CanIgnoreIncludes)
-{
-}
-
 void QFileInfoExists::VisitStmt(clang::Stmt *stmt)
 {
     auto *existsCall = dyn_cast<CXXMemberCallExpr>(stmt);
