@@ -15,13 +15,6 @@
 
 using namespace clang;
 
-QtMacros::QtMacros(const std::string &name, ClazyContext *context)
-    : CheckBase(name, context)
-{
-    enablePreProcessorCallbacks();
-    context->enablePreprocessorVisitor();
-}
-
 void QtMacros::VisitMacroDefined(const Token &MacroNameTok)
 {
     if (m_OSMacroExists) {
