@@ -25,7 +25,7 @@
 #include <llvm/ADT/StringRef.h>
 #include <llvm/Support/Casting.h>
 
-#include <assert.h>
+#include <cassert>
 
 using namespace clang;
 
@@ -45,11 +45,6 @@ static bool isMemberVariable(Expr *expr)
 // This got a bit messy since each Qt container produces a different AST, for example
 // QVector::iterator isn't even a class, it's a typedef.
 
-StrictIterators::StrictIterators(const std::string &name, ClazyContext *context)
-    : CheckBase(name, context, Option_CanIgnoreIncludes)
-{
-}
-
 void StrictIterators::VisitStmt(clang::Stmt *stmt)
 {
     if (handleOperator(dyn_cast<CXXOperatorCallExpr>(stmt))) {
@@ -66,7 +61,7 @@ bool StrictIterators::handleImplicitCast(ImplicitCastExpr *implicitCast)
         return false;
     }
 
-    const std::string nameTo = clazy::simpleTypeName(implicitCast->getType(), m_context->ci.getLangOpts());
+    const std::string nameTo = clazy::simpleTypeName(implicitCast->getType(), lo());
 
     const QualType typeTo = implicitCast->getType();
     CXXRecordDecl *recordTo = clazy::parentRecordForTypedef(typeTo);
@@ -136,7 +131,7 @@ bool StrictIterators::handleImplicitCast(ImplicitCastExpr *implicitCast)
         return false;
     }
 
-    const std::string nameFrom = clazy::simpleTypeName(typeFrom, m_context->ci.getLangOpts());
+    const std::string nameFrom = clazy::simpleTypeName(typeFrom, lo());
     const bool nameFromIsIterator = nameFrom == "iterator" || clazy::endsWith(nameFrom, "::iterator");
     if (!nameFromIsIterator) {
         return false;
