@@ -25,14 +25,14 @@
 #include <llvm/ADT/StringRef.h>
 #include <llvm/Support/Casting.h>
 
-#include <stdlib.h>
+#include <cstdlib>
 #include <string>
 #include <vector>
 
 using namespace clang;
 
-UnusedNonTrivialVariable::UnusedNonTrivialVariable(const std::string &name, ClazyContext *context)
-    : CheckBase(name, context, Option_CanIgnoreIncludes)
+UnusedNonTrivialVariable::UnusedNonTrivialVariable(const std::string &name, Options options)
+    : CheckBase(name, options)
 {
     const char *user_blacklist = getenv("CLAZY_UNUSED_NON_TRIVIAL_VARIABLE_BLACKLIST");
     const char *user_whitelist = getenv("CLAZY_UNUSED_NON_TRIVIAL_VARIABLE_WHITELIST");
