@@ -22,11 +22,8 @@
 class WritingToTemporary : public CheckBase
 {
 public:
-    explicit WritingToTemporary(const std::string &name, ClazyContext *context);
+    explicit WritingToTemporary(const std::string &name, Options options);
     void VisitStmt(clang::Stmt *stmt) override;
-
-private:
-    const bool m_widenCriteria;
 };
 
 #endif
