@@ -23,11 +23,6 @@
 
 using namespace clang;
 
-WrongQGlobalStatic::WrongQGlobalStatic(const std::string &name, ClazyContext *context)
-    : CheckBase(name, context)
-{
-}
-
 void WrongQGlobalStatic::VisitStmt(clang::Stmt *stmt)
 {
     auto *ctorExpr = dyn_cast<CXXConstructExpr>(stmt);
@@ -44,7 +39,7 @@ void WrongQGlobalStatic::VisitStmt(clang::Stmt *stmt)
     }
 
     SourceLocation loc = stmt->getBeginLoc();
-    if (clazy::isInMacro(&m_astContext, loc, "Q_GLOBAL_STATIC_WITH_ARGS")) {
+    if (clazy::isInMacro(astContext(), loc, "Q_GLOBAL_STATIC_WITH_ARGS")) {
         return;
     }
 
