@@ -24,11 +24,6 @@
 
 using namespace clang;
 
-ChildEventQObjectCast::ChildEventQObjectCast(const std::string &name, ClazyContext *context)
-    : CheckBase(name, context, Option_CanIgnoreIncludes)
-{
-}
-
 void ChildEventQObjectCast::VisitDecl(Decl *decl)
 {
     auto *childEventMethod = dyn_cast<CXXMethodDecl>(decl);
