@@ -6,7 +6,6 @@
 */
 
 #include "connect-3arg-lambda.h"
-#include "ClazyContext.h"
 #include "HierarchyUtils.h"
 #include "QtUtils.h"
 
@@ -23,11 +22,6 @@ using namespace clang;
 
 using uint = unsigned;
 
-Connect3ArgLambda::Connect3ArgLambda(const std::string &name, ClazyContext *context)
-    : CheckBase(name, context, Option_CanIgnoreIncludes)
-{
-}
-
 void Connect3ArgLambda::VisitStmt(clang::Stmt *stmt)
 {
     auto *callExpr = dyn_cast<CallExpr>(stmt);
@@ -74,7 +68,6 @@ void Connect3ArgLambda::VisitStmt(clang::Stmt *stmt)
     }
 
     DeclRefExpr *senderDeclRef = nullptr;
-    const MemberExpr *senderMemberExpr = nullptr;
 
     Stmt *s = callExpr->getArg(0);
     while (s) {
@@ -82,7 +75,7 @@ void Connect3ArgLambda::VisitStmt(clang::Stmt *stmt)
             break;
         }
 
-        if ((senderMemberExpr = dyn_cast<MemberExpr>(s))) {
+        if (isa<MemberExpr>(s)) {
             break;
         }
 
