@@ -19,12 +19,6 @@
 
 using namespace clang;
 
-ConstSignalOrSlot::ConstSignalOrSlot(const std::string &name, ClazyContext *context)
-    : CheckBase(name, context, Option_CanIgnoreIncludes)
-{
-    context->enableAccessSpecifierManager();
-}
-
 void ConstSignalOrSlot::VisitStmt(clang::Stmt *stmt)
 {
     auto *call = dyn_cast<CallExpr>(stmt);
