@@ -19,11 +19,6 @@
 
 using namespace clang;
 
-InstallEventFilter::InstallEventFilter(const std::string &name, ClazyContext *context)
-    : CheckBase(name, context, Option_CanIgnoreIncludes)
-{
-}
-
 void InstallEventFilter::VisitStmt(clang::Stmt *stmt)
 {
     auto *memberCallExpr = dyn_cast<CXXMemberCallExpr>(stmt);
