@@ -15,13 +15,11 @@
 class ReadlockDetaching : public CheckBase
 {
 public:
-    explicit ReadlockDetaching(const std::string &name, ClazyContext *context);
-    void VisitDecl(clang::Decl *) override;
-    void VisitStmt(clang::Stmt *) override;
+    using CheckBase::CheckBase;
     void registerASTMatchers(clang::ast_matchers::MatchFinder &) override;
 
 private:
-    ClazyAstMatcherCallback *const m_astMatcherCallBack;
+    std::unique_ptr<ClazyAstMatcherCallback> m_astMatcherCallBack;
 };
 
 #endif
