@@ -15,11 +15,6 @@
 
 using namespace clang;
 
-RuleOfTwoSoft::RuleOfTwoSoft(const std::string &name, ClazyContext *context)
-    : RuleOfBase(name, context)
-{
-}
-
 void RuleOfTwoSoft::VisitStmt(Stmt *s)
 {
     if (auto *op = dyn_cast<CXXOperatorCallExpr>(s)) {
