@@ -56,12 +56,6 @@ static bool hasPublicCopyInAncestors(const CXXRecordDecl *record)
     return false;
 }
 
-CopyablePolymorphic::CopyablePolymorphic(const std::string &name, ClazyContext *context)
-    : CheckBase(name, context)
-{
-    context->enableAccessSpecifierManager();
-}
-
 void CopyablePolymorphic::VisitDecl(clang::Decl *decl)
 {
     auto *record = dyn_cast<CXXRecordDecl>(decl);
