@@ -18,11 +18,6 @@
 
 using namespace clang;
 
-CtorMissingParentArgument::CtorMissingParentArgument(const std::string &name, ClazyContext *context)
-    : CheckBase(name, context)
-{
-}
-
 static std::string expectedParentTypeFor(CXXRecordDecl *decl)
 {
     if (clazy::derivesFrom(decl, "QWidget")) {
@@ -42,7 +37,7 @@ void CtorMissingParentArgument::VisitDecl(Decl *decl)
     auto *record = dyn_cast<CXXRecordDecl>(decl);
     bool ok = false;
 
-    if (!clazy::isQObject(record)) {
+    if (!record || !clazy::isQObject(record)) {
         return;
     }
 
