@@ -32,8 +32,7 @@
 #include <llvm/Support/Casting.h>
 #include <llvm/Support/raw_ostream.h>
 
-#include <assert.h>
-
+#include <cassert>
 #include <utility>
 
 using namespace clang;
@@ -63,20 +62,15 @@ enum Fixit {
 struct Latin1Expr {
     CXXConstructExpr *qlatin1ctorexpr;
     bool enableFixit;
-    bool isValid() const
+    [[nodiscard]] bool isValid() const
     {
         return qlatin1ctorexpr != nullptr;
     }
 };
 
-QStringAllocations::QStringAllocations(const std::string &name, ClazyContext *context)
-    : CheckBase(name, context, Option_CanIgnoreIncludes)
-{
-}
-
 void QStringAllocations::VisitStmt(clang::Stmt *stm)
 {
-    if (m_context->isQtDeveloper() && clazy::isBootstrapping(m_context->ci.getPreprocessorOpts())) {
+    if (m_context->isQtDeveloper() && clazy::isBootstrapping(m_context->m_pp)) {
         // During bootstrap many QString::fromLatin1() are used instead of tr(), which causes
         // much noise
         return;
@@ -280,18 +274,14 @@ void QStringAllocations::VisitCtor(CXXConstructExpr *ctorExpr)
                         && dyn_cast_or_null<CXXBindTemporaryExpr>(clazy::parent(m_context->parentMap, ctorExpr));
                     if (shouldRemoveQString) {
                         // This is the case of QString(QLatin1String("foo")), which we just fixed to be QString(QStringLiteral("foo")), so now remove QString
-                        auto removalFixits = clazy::fixItRemoveToken(&m_astContext, ctorExpr, true);
-                        if (removalFixits.empty()) {
-                            queueManualFixitWarning(ctorExpr->getBeginLoc(), "Internal error: invalid start or end location");
-                        } else {
+                        auto removalFixits = clazy::fixItRemoveToken(astContext(), ctorExpr, true);
+                        if (!removalFixits.empty()) {
                             clazy::append(removalFixits, fixits);
                         }
                     }
                 } else {
                     fixits = fixItReplaceWordWithWordInTernary(ternary);
                 }
-            } else {
-                queueManualFixitWarning(qlatin1Ctor->getBeginLoc(), "Can't use QStringLiteral in macro");
             }
         }
 
@@ -315,8 +305,6 @@ void QStringAllocations::VisitCtor(CXXConstructExpr *ctorExpr)
                             fixits = fixItReplaceWordWithWord(ctorExpr, "QLatin1String", "QString");
                         } else if (!ctorExpr->getBeginLoc().isMacroID()) {
                             fixits = fixItReplaceWordWithWord(ctorExpr, "QStringLiteral", "QString");
-                        } else {
-                            queueManualFixitWarning(ctorExpr->getBeginLoc(), "Can't use QStringLiteral in macro.");
                         }
                     } else {
                         auto *parentMemberCallExpr =
@@ -360,10 +348,8 @@ std::vector<FixItHint> QStringAllocations::fixItReplaceWordWithWord(clang::Stmt
     }
 
     std::vector<FixItHint> fixits;
-    FixItHint fixit = clazy::fixItReplaceWordWithWord(&m_astContext, begin, replacement, replacee);
-    if (fixit.isNull()) {
-        queueManualFixitWarning(begin->getBeginLoc(), "");
-    } else {
+    FixItHint fixit = clazy::fixItReplaceWordWithWord(astContext(), begin, replacement, replacee);
+    if (!fixit.isNull()) {
         fixits.push_back(fixit);
     }
 
@@ -506,10 +492,7 @@ std::vector<FixItHint> QStringAllocations::fixItReplaceFromLatin1OrFromUtf8(Call
         auto methodNameLoc = Lexer::getLocForEndOfToken(scopeOperatorLoc, -1, sm(), lo());
         SourceRange range(callExpr->getBeginLoc(), methodNameLoc);
         fixits.push_back(FixItHint::CreateReplacement(range, replacement));
-    } else {
-        queueManualFixitWarning(callExpr->getBeginLoc(), "Internal error: literal is null");
     }
-
     return fixits;
 }
 
@@ -535,7 +518,7 @@ std::vector<FixItHint> QStringAllocations::fixItRawLiteral(StringLiteral *lt, co
 {
     std::vector<FixItHint> fixits;
 
-    SourceRange range = clazy::rangeForLiteral(&m_astContext, lt);
+    SourceRange range = clazy::rangeForLiteral(astContext(), lt);
     if (range.isInvalid()) {
         if (lt) {
             queueManualFixitWarning(lt->getBeginLoc(), "Internal error: Can't calculate source location");
@@ -544,9 +527,7 @@ std::vector<FixItHint> QStringAllocations::fixItRawLiteral(StringLiteral *lt, co
     }
 
     SourceLocation start = lt->getBeginLoc();
-    if (start.isMacroID()) {
-        queueManualFixitWarning(start, "Can't use QStringLiteral in macro");
-    } else {
+    if (!start.isMacroID()) {
         if (Utils::literalContainsEscapedBytes(lt, sm(), lo())) {
             return {};
         }
@@ -574,7 +555,6 @@ std::vector<FixItHint> QStringAllocations::fixItRawLiteral(StringLiteral *lt, co
 
         std::string revisedReplacement = lt->getLength() == 0 ? "QLatin1String" : replacement; // QLatin1String("") is better than QStringLiteral("")
         if (revisedReplacement == "QStringLiteral" && lt->getBeginLoc().isMacroID()) {
-            queueManualFixitWarning(lt->getBeginLoc(), "Can't use QStringLiteral in macro...");
             return {};
         }
 
@@ -640,9 +620,7 @@ void QStringAllocations::VisitOperatorCall(Stmt *stm)
         }
     }
 
-    if (literals.empty()) {
-        queueManualFixitWarning(stm->getBeginLoc(), "Couldn't find literal");
-    } else {
+    if (!literals.empty()) {
         const std::string replacement = Utils::isAscii(literals[0]) ? "QLatin1String" : "QStringLiteral";
         fixits = fixItRawLiteral(literals[0], replacement, operatorCall);
     }
