@@ -23,8 +23,8 @@
 
 using namespace clang;
 
-RuleOfThree::RuleOfThree(const std::string &name, ClazyContext *context)
-    : RuleOfBase(name, context)
+RuleOfThree::RuleOfThree(const std::string &name, Options options)
+    : RuleOfBase(name, options)
 {
     m_filesToIgnore = {"qrc_"};
 }
@@ -47,7 +47,7 @@ void RuleOfThree::VisitDecl(clang::Decl *decl)
 
     const SourceLocation recordStart = record->getBeginLoc();
     if (recordStart.isMacroID()) {
-        if (clazy::isInMacro(&m_astContext, recordStart, "Q_GLOBAL_STATIC_INTERNAL")) {
+        if (clazy::isInMacro(astContext(), recordStart, "Q_GLOBAL_STATIC_INTERNAL")) {
             return;
         }
     }
@@ -97,21 +97,21 @@ void RuleOfThree::VisitDecl(clang::Decl *decl)
     std::vector<StringRef> hasList;
     std::vector<StringRef> missingList;
     if (hasUserDtor) {
-        hasList.push_back("dtor");
+        hasList.emplace_back("dtor");
     } else {
-        missingList.push_back("dtor");
+        missingList.emplace_back("dtor");
     }
 
     if (hasUserCopyCtor) {
-        hasList.push_back("copy-ctor");
+        hasList.emplace_back("copy-ctor");
     } else {
-        missingList.push_back("copy-ctor");
+        missingList.emplace_back("copy-ctor");
     }
 
     if (hasUserCopyAssign) {
-        hasList.push_back("copy-assignment");
+        hasList.emplace_back("copy-assignment");
     } else {
-        missingList.push_back("copy-assignment");
+        missingList.emplace_back("copy-assignment");
     }
 
     const int numNotImplemented = missingList.size();
