@@ -28,17 +28,6 @@
 
 using namespace clang;
 
-enum Aggressiveness {
-    NormalAggressiveness = 0,
-    AlsoCheckFunctionCallsAggressiveness = 1 // too many false positives
-};
-
-AssertWithSideEffects::AssertWithSideEffects(const std::string &name, ClazyContext *context)
-    : CheckBase(name, context, Option_CanIgnoreIncludes)
-    , m_aggressiveness(NormalAggressiveness)
-{
-}
-
 static bool functionIsOk(StringRef name)
 {
     static const std::vector<StringRef> whitelist = {
@@ -71,7 +60,7 @@ static bool methodIsOK(const std::string &name)
 void AssertWithSideEffects::VisitStmt(Stmt *stm)
 {
     const SourceLocation stmStart = stm->getBeginLoc();
-    if (!clazy::isInMacro(&m_astContext, stmStart, "Q_ASSERT")) {
+    if (!clazy::isInMacro(astContext(), stmStart, "Q_ASSERT")) {
         return;
     }
 
