@@ -15,10 +15,8 @@
 class HeapAllocatedSmallTrivialType : public CheckBase
 {
 public:
-    explicit HeapAllocatedSmallTrivialType(const std::string &name, ClazyContext *context);
+    using CheckBase::CheckBase;
     void VisitDecl(clang::Decl *decl) override;
-
-private:
 };
 
 #endif
