@@ -17,11 +17,6 @@
 
 using namespace clang;
 
-QHashWithCharPointerKey::QHashWithCharPointerKey(const std::string &name, ClazyContext *context)
-    : CheckBase(name, context)
-{
-}
-
 void QHashWithCharPointerKey::VisitDecl(clang::Decl *decl)
 {
     auto *tsdecl = Utils::templateSpecializationFromVarDecl(decl);
