@@ -29,13 +29,6 @@
 
 using namespace clang;
 
-QPropertyTypeMismatch::QPropertyTypeMismatch(const std::string &name, ClazyContext *context)
-    : CheckBase(name, context)
-{
-    enablePreProcessorCallbacks();
-    context->enableVisitallTypeDefs();
-}
-
 void QPropertyTypeMismatch::VisitDecl(clang::Decl *decl)
 {
     if (auto *method = dyn_cast<CXXMethodDecl>(decl)) {
