@@ -15,10 +15,8 @@
 class QRequiredResultCandidates : public CheckBase
 {
 public:
-    explicit QRequiredResultCandidates(const std::string &name, ClazyContext *context);
+    using CheckBase::CheckBase;
     void VisitDecl(clang::Decl *) override;
-
-private:
 };
 
 #endif
