@@ -19,11 +19,6 @@
 
 using namespace clang;
 
-QStringVarargs::QStringVarargs(const std::string &name, ClazyContext *context)
-    : CheckBase(name, context, Option_CanIgnoreIncludes)
-{
-}
-
 void QStringVarargs::VisitStmt(clang::Stmt *stmt)
 {
     auto *binop = dyn_cast<BinaryOperator>(stmt);
