@@ -23,13 +23,6 @@
 
 using namespace clang;
 
-QtKeywordEmit::QtKeywordEmit(const std::string &name, ClazyContext *context)
-    : CheckBase(name, context)
-{
-    enablePreProcessorCallbacks();
-    context->enablePreprocessorVisitor();
-}
-
 void QtKeywordEmit::VisitMacroExpands(const Token &macroNameTok, const SourceRange &range, const clang::MacroInfo *minfo)
 {
     IdentifierInfo *ii = macroNameTok.getIdentifierInfo();
