@@ -29,13 +29,6 @@
 
 using namespace clang;
 
-Qt6FwdFixes::Qt6FwdFixes(const std::string &name, ClazyContext *context)
-    : CheckBase(name, context, Option_CanIgnoreIncludes)
-{
-    enablePreProcessorCallbacks();
-    context->enablePreprocessorVisitor();
-}
-
 static std::set<std::string> interestingFwdDecl = {
     "QCache", "QHash",   "QMap",        "QMultiHash",     "QMultiMap", "QPair",    "QQueue",       "QSet",        "QStack",       "QVarLengthArray",
     "QList",  "QVector", "QStringList", "QByteArrayList", "QMetaType", "QVariant", "QVariantList", "QVariantMap", "QVariantHash", "QVariantPair"};
@@ -103,7 +96,7 @@ void Qt6FwdFixes::VisitDecl(clang::Decl *decl)
         return;
     }
 
-    const std::string currentFile = m_sm.getFilename(decl->getLocation()).str();
+    const std::string currentFile = sm().getFilename(decl->getLocation()).str();
     if (m_currentFile != currentFile) {
         m_currentFile = currentFile;
         m_including_qcontainerfwd = false;
@@ -112,7 +105,7 @@ void Qt6FwdFixes::VisitDecl(clang::Decl *decl)
         }
     }
 
-    SourceLocation endLoc = locForNextSemiColon(recDecl->getBeginLoc(), m_sm, lo());
+    SourceLocation endLoc = locForNextSemiColon(recDecl->getBeginLoc(), sm(), lo());
 
     SourceLocation beginLoc;
     auto *tempclass = recDecl->getDescribedClassTemplate();
@@ -159,7 +152,7 @@ void Qt6FwdFixes::VisitInclusionDirective(clang::SourceLocation HashLoc,
                                           bool /*ModuleImported*/,
                                           clang::SrcMgr::CharacteristicKind /*FileType*/)
 {
-    auto current_file = m_sm.getFilename(HashLoc);
+    auto current_file = sm().getFilename(HashLoc);
     if (FileName.str() == "QtCore/qcontainerfwd.h") {
         m_qcontainerfwd_included_in_files.insert(current_file);
         return;
