@@ -6,7 +6,6 @@
 */
 
 #include "qt6-header-fixes.h"
-#include "ClazyContext.h"
 #include "FixItUtils.h"
 #include "Utils.h"
 
@@ -206,8 +205,8 @@ static bool newOldHeaderFileMatch(const std::string &FileNameOld, std::string &F
     return true;
 }
 
-Qt6HeaderFixes::Qt6HeaderFixes(const std::string &name, ClazyContext *context)
-    : CheckBase(name, context, Option_CanIgnoreIncludes)
+Qt6HeaderFixes::Qt6HeaderFixes(const std::string &name, Options options)
+    : CheckBase(name, options)
 {
     m_filesToIgnore = {"qeventtransition.h",
                        "qfinalstate.h",
@@ -242,7 +241,6 @@ Qt6HeaderFixes::Qt6HeaderFixes(const std::string &name, ClazyContext *context)
                        "qopenglfunctions_4_4_core.h",
                        "qopenglfunctions_4_5_compatibility.h",
                        "qopenglfunctions_4_5_core.h"};
-    enablePreProcessorCallbacks();
 }
 
 void Qt6HeaderFixes::VisitInclusionDirective(clang::SourceLocation HashLoc,
