@@ -20,16 +20,11 @@
 #include <llvm/ADT/StringRef.h>
 #include <llvm/Support/Casting.h>
 
-#include <ctype.h>
+#include <cctype>
 #include <vector>
 
 using namespace clang;
 
-QVariantTemplateInstantiation::QVariantTemplateInstantiation(const std::string &name, ClazyContext *context)
-    : CheckBase(name, context, Option_CanIgnoreIncludes)
-{
-}
-
 static bool isMatchingClass(StringRef name)
 {
     static const std::vector<StringRef> classes = {
