@@ -10,8 +10,6 @@
 
 #include "checkbase.h"
 
-#include <string>
-
 namespace clang
 {
 namespace ast_matchers
@@ -23,13 +21,12 @@ class MatchFinder;
 class UnusedResultCheck : public CheckBase
 {
 public:
-    explicit UnusedResultCheck(const std::string &name, ClazyContext *context);
+    using CheckBase::CheckBase;
     ~UnusedResultCheck() override;
-    void VisitStmt(clang::Stmt *stmt) override;
     void registerASTMatchers(clang::ast_matchers::MatchFinder &) override;
 
 private:
-    std::unique_ptr<ClazyAstMatcherCallback> m_astMatcherCallBack; // TODO: add std::propagate_const
+    std::unique_ptr<ClazyAstMatcherCallback> m_astMatcherCallBack;
 };
 
 #endif
