@@ -8,17 +8,13 @@
 */
 
 #include "use-arrow-operator-instead-of-data.h"
+#include "StringUtils.h"
+#include "Utils.h"
 
-#include "HierarchyUtils.h"
 #include <clang/AST/ExprCXX.h>
 
 using namespace clang;
 
-UseArrowOperatorInsteadOfData::UseArrowOperatorInsteadOfData(const std::string &name, ClazyContext *context)
-    : CheckBase(name, context)
-{
-}
-
 void UseArrowOperatorInsteadOfData::VisitStmt(clang::Stmt *stmt)
 {
     auto *ce = dyn_cast<CXXMemberCallExpr>(stmt);
@@ -58,7 +54,7 @@ void UseArrowOperatorInsteadOfData::VisitStmt(clang::Stmt *stmt)
 
     // find '.' in ptr.data()
     int dotOffset = 0;
-    const char *d = m_sm.getCharacterData(begin);
+    const char *d = sm().getCharacterData(begin);
     while (*d != '.') {
         dotOffset--;
         d--;
