@@ -17,10 +17,8 @@
 class UseArrowOperatorInsteadOfData : public CheckBase
 {
 public:
-    explicit UseArrowOperatorInsteadOfData(const std::string &name, ClazyContext *context);
+    using CheckBase::CheckBase;
     void VisitStmt(clang::Stmt *) override;
-
-private:
 };
 
 #endif
