@@ -105,6 +105,9 @@ void testSubscriptOperator()
     getMap()[0]; // Warning
     auto m = getMap();
     m[0];
+
+    getList()  [0]; // Warning, test correct fixit range here
+    getList()[   0  ]; // Warning, test correct fixit range here
 }
 
 typedef QList<int> IntList;
@@ -120,8 +123,6 @@ void testDerivedClass()
 {
     getStringList().first(); // Warning
     getStringList()[0]; // Warning
-                        //
-                        //
 }
 
 void testQStringListSpecificMethods()
