@@ -48,6 +48,8 @@ using namespace Foo; // Comes after, so shouldn't have influence
 int main() { return 0; }
 #if QT_VERSION_MAJOR == 5
 #include "namespaces.qt5.moc_"
+#elif Q_MOC_OUTPUT_REVISION == 69
+#include "namespaces.qt6.moc_69"
 #else
 #include "namespaces.qt6.moc_"
 #endif
