@@ -4,7 +4,7 @@ void test()
 {
     int i = 1, latitude;
     QString s = QString().arg("foo", i); // Warning
-    s = s.arg(s, i, 3); // Warning
+    s = s.arg(s, i, QChar(3)); // Warning
     s = s.arg(1, latitude); // Warning
     s = s.arg(s); // OK
     s = s.arg(s, 1); // OK
