@@ -6,12 +6,6 @@
 
 #include <QtCore/QString>
 
-#if defined(Q_OS_WINDOWS) // Warning, should be Q_OS_WIN
-#endif
-
-#ifdef Q_OS_WINDOWS // Warning, should be Q_OS_WIN
-#endif
-
 #ifdef Q_OS_WIN // OK
 #endif
 
